        function getR(rrw){
           cx=0;
       cx+=1;
       if(rrw==cx){return 1;}
       cx+=1;
       if(rrw==cx){return 8;}
       cx+=1;
       if(rrw==cx){return 18;}
       cx+=1;
       if(rrw==cx){return 24;}
       cx+=1;
       if(rrw==cx){return 44;}
       cx+=1;
       if(rrw==cx){return 45;}
return -1;}
